## 0.2.1 (2022-09-17)

### Fix

- Removed unused branches

## 0.2.0 (2022-09-17)

### Fix

- Close line after each segment

### Feat

- Render QR code using large paths

## 0.1.1 (2022-09-04)

### Fix

- Added missing setuptools_scm

## 0.1.0 (2022-09-04)

### Fix

- Replaced wrong badge syntax
- Removed not working configurations
- Removed unused poetry
- RML is not detected, removing from pre-commit

### Feat

- Added CI configuration
- Added pylint configuration
- Added tests
- Added commitizen
- Added setuptools support
- Added pre-commit hook
